#!/usr/bin/env python
# encoding: utf-8
"""
fileconvert.py

Created by David Kreitschmann on 2012-05-02.

Konvertiert Binärdateien in das Format für den Packer bzw. Entpacker
"""

import sys
import getopt


help_message = '''
-t <file> convert text to binary
-b <file> convert binary to text
-o <file> output file
'''

def byte_2_binary_string(inbyte):
    out = []
    inbyte = int(inbyte)
    for mask in (128,64,32,16,8,4,2,1):
        bit = (mask & inbyte) and "1" or "0"
        out.append(bit)
    return "".join(out)


class Usage(Exception):
    def __init__(self, msg):
        self.msg = msg


def main(argv=None):
    binaryfile = None
    textfile = None
    output = None
    if argv is None:
        argv = sys.argv
    try:
        try:
            opts, args = getopt.getopt(argv[1:], "b:o:t:", ["help", "output="])
        except getopt.error, msg:
            raise Usage(msg)
    
        # option processing
        for option, value in opts:
            if option == "-b":
                binaryfile = value
            if option == "-t":
                textfile = value
            if option in ("-h", "--help"):
                raise Usage(help_message)
            if option in ("-o", "--output"):
                output = value
    
        if (not (binaryfile or textfile)) or (binaryfile and textfile) or not output:
            raise Usage(help_message)
            
        if binaryfile:
            infile = open(binaryfile,"r")
            outfile = open(output,"w")
            count = 0
            for c in infile.read():
                outfile.write(byte_2_binary_string(ord(c)))
                count+=1
                if count >=79:
                    count = 0
                    outfile.write("\n");
            outfile.write("\n");
            outfile.close()
            infile.close()
            
        if  textfile:
            infile = open(textfile,"r")
            outfile = open(output,"w")
            mask=128
            current_byte=0
            for c in infile.read():
                if c=="1":
                    current_byte+=mask
                    mask=mask>>1
                elif c=="0":
                    mask=mask>>1
                if mask==0:
                    outfile.write(chr(current_byte))
                    mask=128
                    current_byte=0
            outfile.close()
            infile.close()
                
            
    except Usage, err:
        print >> sys.stderr, sys.argv[0].split("/")[-1] + ": " + str(err.msg)
        print >> sys.stderr, "\t for help use --help"
        return 2


if __name__ == "__main__":
    sys.exit(main())
